diff src/protocols/msn/userlist.c @ 12318:e346a085bb4f

[gaim-migrate @ 14622] Try to remove the word contact from the UI as much as possible. committer: Tailor Script <tailor@pidgin.im>
author Richard Laager <rlaager@wiktel.com>
date Sun, 04 Dec 2005 17:47:37 +0000
parents 3a05b53a589e
children 553dd80f6130
line wrap: on
line diff
--- a/src/protocols/msn/userlist.c	Sun Dec 04 17:47:05 2005 +0000
+++ b/src/protocols/msn/userlist.c	Sun Dec 04 17:47:37 2005 +0000
@@ -262,7 +262,7 @@
 		gc = gaim_account_get_connection(account);
 
 		gaim_debug_info("msn",
-						"%s has added you to his or her contact list.\n",
+						"%s has added you to his or her buddy list.\n",
 						passport);
 
  		convo = gaim_find_conversation_with_account(GAIM_CONV_TYPE_IM, passport, account);
@@ -272,7 +272,7 @@
  
  			buddy = gaim_find_buddy(account, passport);
  			msg = g_strdup_printf(
- 				_("%s has added you to his or her contact list."),
+ 				_("%s has added you to his or her buddy list."),
  				buddy ? gaim_buddy_get_contact_alias(buddy) : passport);
  			gaim_conv_im_write(GAIM_CONV_IM(convo), passport, msg,
  				GAIM_MESSAGE_SYSTEM, time(NULL));
@@ -326,7 +326,7 @@
 		GaimConversation *convo;
 
 		gaim_debug_info("msn",
-						"%s has removed you from his or her contact list.\n",
+						"%s has removed you from his or her buddy list.\n",
 						passport);
 
 		convo = gaim_find_conversation_with_account(GAIM_CONV_TYPE_IM, passport, account);
@@ -336,7 +336,7 @@
 
 			buddy = gaim_find_buddy(account, passport);
 			msg = g_strdup_printf(
-				_("%s has removed you from his or her contact list."),
+				_("%s has removed you from his or her buddy list."),
 				buddy ? gaim_buddy_get_contact_alias(buddy) : passport);
 			gaim_conv_im_write(GAIM_CONV_IM(convo), passport, msg,
 				GAIM_MESSAGE_SYSTEM, time(NULL));
@@ -412,7 +412,7 @@
 
 	if (list_op & MSN_LIST_RL_OP)
 	{
 		/* These are users who have us on their contact list. */
 		/* TODO: what does store name is when this happens? */
 
 		if (!(list_op & (MSN_LIST_AL_OP | MSN_LIST_BL_OP)))
@@ -412,7 +412,7 @@
 	if (list_op & MSN_LIST_RL_OP)
 	{
-		/* These are users who have us on their contact list. */
+		/* These are users who have us on their buddy list. */
 		/* TODO: what does store name is when this happens? */
 